/*
 * Copyright (C) 2016 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.syndesis.server.openshift;

import org.springframework.util.StringUtils;

import java.util.EnumSet;
import java.util.HashSet;
import java.util.Optional;
import java.util.Set;

public class ExposureHelper {

    private final String managementUrlFor3scale;

    public ExposureHelper(OpenShiftConfigurationProperties config) {
        this.managementUrlFor3scale = config.getManagementUrlFor3scale();
    }

    public Set<String> getExposureMeans() {
        Set<String> result = new HashSet<>();
        result.add(Exposure.ROUTE.toString());
        if (!StringUtils.isEmpty(managementUrlFor3scale)) {
            result.add(Exposure._3SCALE.toString());
        }
        return result;
    }

    public EnumSet<Exposure> determineExposure(Optional<String> exposure) {
        if (!StringUtils.isEmpty(managementUrlFor3scale) &&
            Exposure._3SCALE.toString().equals(exposure.orElse(Exposure._3SCALE.toString()))) {
            return EnumSet.of(Exposure.SERVICE, Exposure._3SCALE);
        }

        return EnumSet.of(Exposure.ROUTE, Exposure.SERVICE);
    }

    public String getManagementUrl(Optional<String> exposure) {
        if (determineExposure(exposure).contains(Exposure._3SCALE)) {
            return managementUrlFor3scale;
        } else {
            return null;
        }
    }
}
